@@ -117,6 +117,7 @@ intern pth_t pth_pqueue_delmax(pth_pqueue_t *q)
         t->q_prev->q_next = t->q_next;
         t->q_next->q_prev = t->q_prev;
         t->q_next->q_prio = t->q_prio - t->q_next->q_prio;
+        t->q_prio = 0;
         q->q_head = t->q_next;
         q->q_num--;
     }
@@ -144,6 +145,7 @@ intern void pth_pqueue_delete(pth_pqueue_t *q, pth_t t)
             t->q_prev->q_next = t->q_next;
             t->q_next->q_prev = t->q_prev;
             t->q_next->q_prio = t->q_prio - t->q_next->q_prio;
+            t->q_prio = 0;
             q->q_head = t->q_next;
             q->q_num--;
         }
@@ -153,6 +155,7 @@ intern void pth_pqueue_delete(pth_pqueue_t *q, pth_t t)
         t->q_next->q_prev = t->q_prev;
         if (t->q_next != q->q_head)
             t->q_next->q_prio += t->q_prio;
+        t->q_prio = 0;
         q->q_num--;
     }
     return;
@@ -204,6 +207,16 @@ intern void pth_pqueue_increase(pth_pqueue_t *q)
     ((q) == NULL ? NULL : (q)->q_head)
 #endif
 
+/* walk to last thread in queue */
+intern pth_t pth_pqueue_tail(pth_pqueue_t *q)
+{
+    if (q == NULL)
+        return NULL;
+    if (q->q_head == NULL)
+        return NULL;
+    return q->q_head->q_prev;
+}
+
 /* walk to next or previous thread in queue */
 intern pth_t pth_pqueue_walk(pth_pqueue_t *q, pth_t t, int direction)
 {
