@@ -98,12 +98,12 @@ int main(int argc, char *argv[])
     char caLine[MAXLINELEN];
     pth_event_t ev = NULL;
     pth_event_t evt = NULL;
-    pth_t t_worker;
-    pth_t t_ticker;
+    pth_t t_worker = NULL;
+    pth_t t_ticker = NULL;
     pth_attr_t t_attr;
     pth_msgport_t mp = NULL;
     pth_msgport_t mp_worker = NULL;
-    struct query *q;
+    struct query *q = NULL;
     int n;
 
     if (!pth_init()) {
